Class: Google::Apis::WorkspaceeventsV1::DriveOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb

Overview

Additional supported options for serving Drive events.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DriveOptions

Returns a new instance of DriveOptions.



158
159
160
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_descendantsBoolean Also known as: include_descendants?

Optional. Immutable. For subscriptions to Google Drive events, whether to receive events about Drive files that are children of the target folder or shared drive. This field must be true for subscriptions on shared drives. * If false, the subscription only receives events about changes to the folder or shared drive that's specified as the targetResource. * If true, the mimeType field of the file resource must be set to application/vnd.google- apps.folder. For details, see Google Drive event types. Corresponds to the JSON property includeDescendants

Returns:

  • (Boolean)


155
156
157
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 155

def include_descendants
  @include_descendants
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



163
164
165
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 163

def update!(**args)
  @include_descendants = args[:include_descendants] if args.key?(:include_descendants)
end