Class: Google::Apis::WorkspaceeventsV1::NotificationEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb

Overview

The endpoint where the subscription delivers events.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpoint

Returns a new instance of NotificationEndpoint.



334
335
336
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pubsub_topicString

Immutable. The Pub/Sub topic that receives events for the subscription. Format: projects/project/topics/topic`You must create the topic in the same Google Cloud project where you create this subscription. Note: The Google Workspace Events API uses [ordering keys](https://cloud.google.com/pubsub/docs/ ordering) for the benefit of sequential events. If the Cloud Pub/Sub topic has a [message storage policy](https://cloud.google.com/pubsub/docs/resource- location-restriction#exceptions) configured to exclude the nearest Google Cloud region, publishing events with ordering keys will fail. When the topic receives events, the events are encoded as Pub/Sub messages. For details, see the [Google Cloud Pub/Sub Protocol Binding for CloudEvents](https://github.com/ googleapis/google-cloudevents/blob/main/docs/spec/pubsub.md). Corresponds to the JSON propertypubsubTopic`

Returns:

  • (String)


332
333
334
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 332

def pubsub_topic
  @pubsub_topic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



339
340
341
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 339

def update!(**args)
  @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic)
end