Class: Google::Apis::WorkspaceeventsV1::PayloadOptions
- Inherits:
-
Object
- Object
- Google::Apis::WorkspaceeventsV1::PayloadOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb
Overview
Options about what data to include in the event payload. Only supported for Google Chat and Google Drive events.
Instance Attribute Summary collapse
-
#field_mask ⇒ String
Optional.
-
#include_resource ⇒ Boolean
(also: #include_resource?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PayloadOptions
constructor
A new instance of PayloadOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PayloadOptions
Returns a new instance of PayloadOptions.
500 501 502 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 500 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_mask ⇒ String
Optional. If include_resource is set to true, the list of fields to
include in the event payload. Separate fields with a comma. For example, to
include a Google Chat message's sender and create time, enter message.sender,
message.createTime. If omitted, the payload includes all fields for the
resource. If you specify a field that doesn't exist for the resource, the
system ignores the field.
Corresponds to the JSON property fieldMask
488 489 490 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 488 def field_mask @field_mask end |
#include_resource ⇒ Boolean Also known as: include_resource?
Optional. Whether the event payload includes data about the resource that
changed. For example, for an event where a Google Chat message was created,
whether the payload contains data about the Message resource. If false, the
event payload only includes the name of the changed resource.
Corresponds to the JSON property includeResource
497 498 499 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 497 def include_resource @include_resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
505 506 507 508 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 505 def update!(**args) @field_mask = args[:field_mask] if args.key?(:field_mask) @include_resource = args[:include_resource] if args.key?(:include_resource) end |