Class: Google::Apis::WorkspaceeventsV1::SendMessageConfiguration
- Inherits:
-
Object
- Object
- Google::Apis::WorkspaceeventsV1::SendMessageConfiguration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb
Overview
Configuration of a send message request.
Instance Attribute Summary collapse
-
#accepted_output_modes ⇒ Array<String>
The output modes that the agent is expected to respond with.
-
#blocking ⇒ Boolean
(also: #blocking?)
If true, the message will be blocking until the task is completed.
-
#history_length ⇒ Fixnum
The maximum number of messages to include in the history.
-
#push_notification ⇒ Google::Apis::WorkspaceeventsV1::PushNotificationConfig
Configuration for setting up push notifications for task updates.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SendMessageConfiguration
constructor
A new instance of SendMessageConfiguration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SendMessageConfiguration
Returns a new instance of SendMessageConfiguration.
589 590 591 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 589 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accepted_output_modes ⇒ Array<String>
The output modes that the agent is expected to respond with.
Corresponds to the JSON property acceptedOutputModes
568 569 570 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 568 def accepted_output_modes @accepted_output_modes end |
#blocking ⇒ Boolean Also known as: blocking?
If true, the message will be blocking until the task is completed. If false,
the message will be non-blocking and the task will be returned immediately. It
is the caller's responsibility to check for any task updates.
Corresponds to the JSON property blocking
575 576 577 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 575 def blocking @blocking end |
#history_length ⇒ Fixnum
The maximum number of messages to include in the history. if 0, the history
will be unlimited.
Corresponds to the JSON property historyLength
582 583 584 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 582 def history_length @history_length end |
#push_notification ⇒ Google::Apis::WorkspaceeventsV1::PushNotificationConfig
Configuration for setting up push notifications for task updates.
Corresponds to the JSON property pushNotification
587 588 589 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 587 def push_notification @push_notification end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
594 595 596 597 598 599 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 594 def update!(**args) @accepted_output_modes = args[:accepted_output_modes] if args.key?(:accepted_output_modes) @blocking = args[:blocking] if args.key?(:blocking) @history_length = args[:history_length] if args.key?(:history_length) @push_notification = args[:push_notification] if args.key?(:push_notification) end |