Class: Google::Apis::WorkspaceeventsV1::TaskStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb

Overview

A container for the status of a task

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TaskStatus

Returns a new instance of TaskStatus.



1023
1024
1025
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageGoogle::Apis::WorkspaceeventsV1::Message

Message is one unit of communication between client and server. It is associated with a context and optionally a task. Since the server is responsible for the context definition, it must always provide a context_id in its messages. The client can optionally provide the context_id if it knows the context to associate the message to. Similarly for task_id, except the server decides if a task is created and whether to include the task_id. Corresponds to the JSON property message



1011
1012
1013
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1011

def message
  @message
end

#stateString

The current state of this task Corresponds to the JSON property state

Returns:

  • (String)


1016
1017
1018
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1016

def state
  @state
end

#timestampString

Timestamp when the status was recorded. Example: "2023-10-27T10:00:00Z" Corresponds to the JSON property timestamp

Returns:

  • (String)


1021
1022
1023
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1021

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1028
1029
1030
1031
1032
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1028

def update!(**args)
  @message = args[:message] if args.key?(:message)
  @state = args[:state] if args.key?(:state)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end