Module: Google::Apis::WorkspaceeventsV1
- Defined in:
- lib/google/apis/workspaceevents_v1.rb,
lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/service.rb,
lib/google/apis/workspaceevents_v1/gem_version.rb,
lib/google/apis/workspaceevents_v1/representations.rb
Overview
Google Workspace Events API
The Google Workspace Events API lets you subscribe to events and manage change notifications across Google Workspace applications.
Defined Under Namespace
Classes: Artifact, AuthenticationInfo, CancelTaskRequest, DataPart, Empty, FilePart, ListSubscriptionsResponse, ListTaskPushNotificationConfigResponse, Message, NotificationEndpoint, Operation, Part, PayloadOptions, PushNotificationConfig, ReactivateSubscriptionRequest, SendMessageConfiguration, SendMessageRequest, Status, StreamResponse, Subscription, Task, TaskArtifactUpdateEvent, TaskPushNotificationConfig, TaskStatus, TaskStatusUpdateEvent, WorkspaceEventsService
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-workspaceevents_v1 gem
"0.22.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260407"- VERSION =
Version of the Google Workspace Events API this client connects to. This is NOT the gem version.
'V1'- AUTH_CHAT_APP_MEMBERSHIPS =
On their own behalf, apps in Google Chat can see, add, update, and remove members from conversations and spaces
'https://www.googleapis.com/auth/chat.app.memberships'- AUTH_CHAT_APP_MEMBERSHIPS_READONLY =
On their own behalf, apps in Google Chat can see members of conversations and spaces
'https://www.googleapis.com/auth/chat.app.memberships.readonly'- AUTH_CHAT_APP_MESSAGES_READONLY =
On their own behalf, apps in Google Chat can see all messages and their associated reactions and message content
'https://www.googleapis.com/auth/chat.app.messages.readonly'- AUTH_CHAT_APP_SPACES =
On their own behalf, apps in Google Chat can create conversations and spaces and see or update their metadata (including history settings and access settings)
'https://www.googleapis.com/auth/chat.app.spaces'- AUTH_CHAT_APP_SPACES_READONLY =
On their own behalf, apps in Google Chat can see conversations and spaces and their metadata (including history settings and access settings)
'https://www.googleapis.com/auth/chat.app.spaces.readonly'- AUTH_CHAT_BOT =
Private Service: https://www.googleapis.com/auth/chat.bot
'https://www.googleapis.com/auth/chat.bot'- AUTH_CHAT_MEMBERSHIPS =
See, add, update, and remove members from conversations and spaces in Google Chat
'https://www.googleapis.com/auth/chat.memberships'- AUTH_CHAT_MEMBERSHIPS_READONLY =
View members in Google Chat conversations.
'https://www.googleapis.com/auth/chat.memberships.readonly'- AUTH_CHAT_MESSAGES =
See, compose, send, update, and delete messages as well as their message content; add, see, and delete reactions to messages.
'https://www.googleapis.com/auth/chat.messages'- AUTH_CHAT_MESSAGES_REACTIONS =
See, add, and delete reactions as well as their reaction content to messages in Google Chat
'https://www.googleapis.com/auth/chat.messages.reactions'- AUTH_CHAT_MESSAGES_REACTIONS_READONLY =
View reactions as well as their reaction content to messages in Google Chat
'https://www.googleapis.com/auth/chat.messages.reactions.readonly'- AUTH_CHAT_MESSAGES_READONLY =
See messages as well as their reactions and message content in Google Chat
'https://www.googleapis.com/auth/chat.messages.readonly'- AUTH_CHAT_SPACES =
Create conversations and spaces and see or update metadata (including history settings and access settings) in Google Chat
'https://www.googleapis.com/auth/chat.spaces'- AUTH_CHAT_SPACES_READONLY =
View chat and spaces in Google Chat
'https://www.googleapis.com/auth/chat.spaces.readonly'- AUTH_DRIVE =
See, edit, create, and delete all of your Google Drive files
'https://www.googleapis.com/auth/drive'- AUTH_DRIVE_FILE =
See, edit, create, and delete only the specific Google Drive files you use with this app
'https://www.googleapis.com/auth/drive.file'- AUTH_DRIVE_METADATA =
View and manage metadata of files in your Google Drive
'https://www.googleapis.com/auth/drive.metadata'- AUTH_DRIVE_METADATA_READONLY =
See information about your Google Drive files
'https://www.googleapis.com/auth/drive.metadata.readonly'- AUTH_DRIVE_READONLY =
See and download all your Google Drive files
'https://www.googleapis.com/auth/drive.readonly'- AUTH_MEETINGS_SPACE_CREATED =
Create, edit, and see information about your Google Meet conferences created by the app.
'https://www.googleapis.com/auth/meetings.space.created'- AUTH_MEETINGS_SPACE_READONLY =
Read information about any of your Google Meet conferences
'https://www.googleapis.com/auth/meetings.space.readonly'