Class: Google::Apis::WorkspaceeventsV1::Artifact
- Inherits:
-
Object
- Object
- Google::Apis::WorkspaceeventsV1::Artifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb
Overview
Artifacts are the container for task completed results. These are similar to Messages but are intended to be the product of a task, as opposed to point-to- point communication.
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Unique identifier (e.g. UUID) for the artifact.
-
#description ⇒ String
A human readable description of the artifact, optional.
-
#extensions ⇒ Array<String>
The URIs of extensions that are present or contributed to this Artifact.
-
#metadata ⇒ Hash<String,Object>
Optional metadata included with the artifact.
-
#name ⇒ String
A human readable name for the artifact.
-
#parts ⇒ Array<Google::Apis::WorkspaceeventsV1::Part>
The content of the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Artifact
constructor
A new instance of Artifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Artifact
Returns a new instance of Artifact.
62 63 64 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 62 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Unique identifier (e.g. UUID) for the artifact. It must be at least unique
within a task.
Corresponds to the JSON property artifactId
35 36 37 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 35 def artifact_id @artifact_id end |
#description ⇒ String
A human readable description of the artifact, optional.
Corresponds to the JSON property description
40 41 42 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 40 def description @description end |
#extensions ⇒ Array<String>
The URIs of extensions that are present or contributed to this Artifact.
Corresponds to the JSON property extensions
45 46 47 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 45 def extensions @extensions end |
#metadata ⇒ Hash<String,Object>
Optional metadata included with the artifact.
Corresponds to the JSON property metadata
50 51 52 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 50 def @metadata end |
#name ⇒ String
A human readable name for the artifact.
Corresponds to the JSON property name
55 56 57 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 55 def name @name end |
#parts ⇒ Array<Google::Apis::WorkspaceeventsV1::Part>
The content of the artifact.
Corresponds to the JSON property parts
60 61 62 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 60 def parts @parts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67 68 69 70 71 72 73 74 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 67 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @description = args[:description] if args.key?(:description) @extensions = args[:extensions] if args.key?(:extensions) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @parts = args[:parts] if args.key?(:parts) end |