Class: Google::Apis::WorkspaceeventsV1::PushNotificationConfig
- Inherits:
-
Object
- Object
- Google::Apis::WorkspaceeventsV1::PushNotificationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb
Overview
Configuration for setting up push notifications for task updates.
Instance Attribute Summary collapse
-
#authentication ⇒ Google::Apis::WorkspaceeventsV1::AuthenticationInfo
Defines authentication details, used for push notifications.
-
#id ⇒ String
A unique identifier (e.g. UUID) for this push notification.
-
#token ⇒ String
Token unique for this task/session Corresponds to the JSON property
token. -
#url ⇒ String
Url to send the notification too Corresponds to the JSON property
url.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PushNotificationConfig
constructor
A new instance of PushNotificationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PushNotificationConfig
Returns a new instance of PushNotificationConfig.
508 509 510 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 508 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication ⇒ Google::Apis::WorkspaceeventsV1::AuthenticationInfo
Defines authentication details, used for push notifications.
Corresponds to the JSON property authentication
491 492 493 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 491 def authentication @authentication end |
#id ⇒ String
A unique identifier (e.g. UUID) for this push notification.
Corresponds to the JSON property id
496 497 498 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 496 def id @id end |
#token ⇒ String
Token unique for this task/session
Corresponds to the JSON property token
501 502 503 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 501 def token @token end |
#url ⇒ String
Url to send the notification too
Corresponds to the JSON property url
506 507 508 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 506 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
513 514 515 516 517 518 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 513 def update!(**args) @authentication = args[:authentication] if args.key?(:authentication) @id = args[:id] if args.key?(:id) @token = args[:token] if args.key?(:token) @url = args[:url] if args.key?(:url) end |