Class: Google::Apis::WorkspaceeventsV1::SendMessageConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb

Overview

Configuration of a send message request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SendMessageConfiguration

Returns a new instance of SendMessageConfiguration.



562
563
564
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accepted_output_modesArray<String>

The output modes that the agent is expected to respond with. Corresponds to the JSON property acceptedOutputModes

Returns:

  • (Array<String>)


541
542
543
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 541

def accepted_output_modes
  @accepted_output_modes
end

#blockingBoolean Also known as: blocking?

If true, the message will be blocking until the task is completed. If false, the message will be non-blocking and the task will be returned immediately. It is the caller's responsibility to check for any task updates. Corresponds to the JSON property blocking

Returns:

  • (Boolean)


548
549
550
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 548

def blocking
  @blocking
end

#history_lengthFixnum

The maximum number of messages to include in the history. if 0, the history will be unlimited. Corresponds to the JSON property historyLength

Returns:

  • (Fixnum)


555
556
557
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 555

def history_length
  @history_length
end

#push_notificationGoogle::Apis::WorkspaceeventsV1::PushNotificationConfig

Configuration for setting up push notifications for task updates. Corresponds to the JSON property pushNotification



560
561
562
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 560

def push_notification
  @push_notification
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



567
568
569
570
571
572
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 567

def update!(**args)
  @accepted_output_modes = args[:accepted_output_modes] if args.key?(:accepted_output_modes)
  @blocking = args[:blocking] if args.key?(:blocking)
  @history_length = args[:history_length] if args.key?(:history_length)
  @push_notification = args[:push_notification] if args.key?(:push_notification)
end