Class: Google::Apis::WorkspaceeventsV1::SendMessageRequest
- Inherits:
-
Object
- Object
- Google::Apis::WorkspaceeventsV1::SendMessageRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb
Overview
/////////// Request Messages ///////////
Instance Attribute Summary collapse
-
#configuration ⇒ Google::Apis::WorkspaceeventsV1::SendMessageConfiguration
Configuration of a send message request.
-
#message ⇒ Google::Apis::WorkspaceeventsV1::Message
Message is one unit of communication between client and server.
-
#metadata ⇒ Hash<String,Object>
Optional metadata for the request.
-
#tenant ⇒ String
Optional tenant, provided as a path parameter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SendMessageRequest
constructor
A new instance of SendMessageRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SendMessageRequest
Returns a new instance of SendMessageRequest.
605 606 607 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration ⇒ Google::Apis::WorkspaceeventsV1::SendMessageConfiguration
Configuration of a send message request.
Corresponds to the JSON property configuration
582 583 584 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 582 def configuration @configuration end |
#message ⇒ Google::Apis::WorkspaceeventsV1::Message
Message is one unit of communication between client and server. It is
associated with a context and optionally a task. Since the server is
responsible for the context definition, it must always provide a context_id in
its messages. The client can optionally provide the context_id if it knows the
context to associate the message to. Similarly for task_id, except the server
decides if a task is created and whether to include the task_id.
Corresponds to the JSON property message
592 593 594 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 592 def @message end |
#metadata ⇒ Hash<String,Object>
Optional metadata for the request.
Corresponds to the JSON property metadata
597 598 599 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 597 def @metadata end |
#tenant ⇒ String
Optional tenant, provided as a path parameter. Experimental, might still
change for 1.0 release.
Corresponds to the JSON property tenant
603 604 605 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 603 def tenant @tenant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
610 611 612 613 614 615 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 610 def update!(**args) @configuration = args[:configuration] if args.key?(:configuration) @message = args[:message] if args.key?(:message) @metadata = args[:metadata] if args.key?(:metadata) @tenant = args[:tenant] if args.key?(:tenant) end |