Class: Google::Apis::WorkspaceeventsV1::Task
- Inherits:
-
Object
- Object
- Google::Apis::WorkspaceeventsV1::Task
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb
Overview
Task is the core unit of action for A2A. It has a current status and when results are created for the task they are stored in the artifact. If there are multiple turns for a task, these are stored in history.
Instance Attribute Summary collapse
-
#artifacts ⇒ Array<Google::Apis::WorkspaceeventsV1::Artifact>
A set of output artifacts for a Task.
-
#context_id ⇒ String
Unique identifier (e.g. UUID) for the contextual collection of interactions ( tasks and messages).
-
#history ⇒ Array<Google::Apis::WorkspaceeventsV1::Message>
protolint:disable REPEATED_FIELD_NAMES_PLURALIZED The history of interactions from a task.
-
#id ⇒ String
Unique identifier (e.g. UUID) for the task, generated by the server for a new task.
-
#metadata ⇒ Hash<String,Object>
protolint:enable REPEATED_FIELD_NAMES_PLURALIZED A key/value object to store custom metadata about a task.
-
#status ⇒ Google::Apis::WorkspaceeventsV1::TaskStatus
A container for the status of a task Corresponds to the JSON property
status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Task
constructor
A new instance of Task.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Task
Returns a new instance of Task.
904 905 906 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 904 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifacts ⇒ Array<Google::Apis::WorkspaceeventsV1::Artifact>
A set of output artifacts for a Task.
Corresponds to the JSON property artifacts
873 874 875 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 873 def artifacts @artifacts end |
#context_id ⇒ String
Unique identifier (e.g. UUID) for the contextual collection of interactions (
tasks and messages). Created by the A2A server.
Corresponds to the JSON property contextId
879 880 881 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 879 def context_id @context_id end |
#history ⇒ Array<Google::Apis::WorkspaceeventsV1::Message>
protolint:disable REPEATED_FIELD_NAMES_PLURALIZED The history of interactions
from a task.
Corresponds to the JSON property history
885 886 887 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 885 def history @history end |
#id ⇒ String
Unique identifier (e.g. UUID) for the task, generated by the server for a new
task.
Corresponds to the JSON property id
891 892 893 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 891 def id @id end |
#metadata ⇒ Hash<String,Object>
protolint:enable REPEATED_FIELD_NAMES_PLURALIZED A key/value object to store
custom metadata about a task.
Corresponds to the JSON property metadata
897 898 899 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 897 def @metadata end |
#status ⇒ Google::Apis::WorkspaceeventsV1::TaskStatus
A container for the status of a task
Corresponds to the JSON property status
902 903 904 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 902 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
909 910 911 912 913 914 915 916 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 909 def update!(**args) @artifacts = args[:artifacts] if args.key?(:artifacts) @context_id = args[:context_id] if args.key?(:context_id) @history = args[:history] if args.key?(:history) @id = args[:id] if args.key?(:id) @metadata = args[:metadata] if args.key?(:metadata) @status = args[:status] if args.key?(:status) end |