Class: Google::Apis::WorkspaceeventsV1::TaskArtifactUpdateEvent
- Inherits:
-
Object
- Object
- Google::Apis::WorkspaceeventsV1::TaskArtifactUpdateEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb
Overview
TaskArtifactUpdateEvent represents a task delta where an artifact has been generated.
Instance Attribute Summary collapse
-
#append ⇒ Boolean
(also: #append?)
Whether this should be appended to a prior one produced Corresponds to the JSON property
append. -
#artifact ⇒ Google::Apis::WorkspaceeventsV1::Artifact
Artifacts are the container for task completed results.
-
#context_id ⇒ String
The id of the context that this task belongs too Corresponds to the JSON property
contextId. -
#last_chunk ⇒ Boolean
(also: #last_chunk?)
Whether this represents the last part of an artifact Corresponds to the JSON property
lastChunk. -
#metadata ⇒ Hash<String,Object>
Optional metadata associated with the artifact update.
-
#task_id ⇒ String
The id of the task for this artifact Corresponds to the JSON property
taskId.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TaskArtifactUpdateEvent
constructor
A new instance of TaskArtifactUpdateEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TaskArtifactUpdateEvent
Returns a new instance of TaskArtifactUpdateEvent.
991 992 993 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 991 def initialize(**args) update!(**args) end |
Instance Attribute Details
#append ⇒ Boolean Also known as: append?
Whether this should be appended to a prior one produced
Corresponds to the JSON property append
960 961 962 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 960 def append @append end |
#artifact ⇒ Google::Apis::WorkspaceeventsV1::Artifact
Artifacts are the container for task completed results. These are similar to
Messages but are intended to be the product of a task, as opposed to point-to-
point communication.
Corresponds to the JSON property artifact
968 969 970 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 968 def artifact @artifact end |
#context_id ⇒ String
The id of the context that this task belongs too
Corresponds to the JSON property contextId
973 974 975 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 973 def context_id @context_id end |
#last_chunk ⇒ Boolean Also known as: last_chunk?
Whether this represents the last part of an artifact
Corresponds to the JSON property lastChunk
978 979 980 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 978 def last_chunk @last_chunk end |
#metadata ⇒ Hash<String,Object>
Optional metadata associated with the artifact update.
Corresponds to the JSON property metadata
984 985 986 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 984 def @metadata end |
#task_id ⇒ String
The id of the task for this artifact
Corresponds to the JSON property taskId
989 990 991 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 989 def task_id @task_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
996 997 998 999 1000 1001 1002 1003 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 996 def update!(**args) @append = args[:append] if args.key?(:append) @artifact = args[:artifact] if args.key?(:artifact) @context_id = args[:context_id] if args.key?(:context_id) @last_chunk = args[:last_chunk] if args.key?(:last_chunk) @metadata = args[:metadata] if args.key?(:metadata) @task_id = args[:task_id] if args.key?(:task_id) end |