Class: Google::Apis::WorkspaceeventsV1::TaskPushNotificationConfig
- Inherits:
-
Object
- Object
- Google::Apis::WorkspaceeventsV1::TaskPushNotificationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb
Instance Attribute Summary collapse
-
#name ⇒ String
The resource name of the config.
-
#push_notification_config ⇒ Google::Apis::WorkspaceeventsV1::PushNotificationConfig
Configuration for setting up push notifications for task updates.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TaskPushNotificationConfig
constructor
A new instance of TaskPushNotificationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TaskPushNotificationConfig
Returns a new instance of TaskPushNotificationConfig.
988 989 990 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The resource name of the config. Format: tasks/task_id/
pushNotificationConfigs/config_id
Corresponds to the JSON property name
981 982 983 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 981 def name @name end |
#push_notification_config ⇒ Google::Apis::WorkspaceeventsV1::PushNotificationConfig
Configuration for setting up push notifications for task updates.
Corresponds to the JSON property pushNotificationConfig
986 987 988 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 986 def push_notification_config @push_notification_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
993 994 995 996 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 993 def update!(**args) @name = args[:name] if args.key?(:name) @push_notification_config = args[:push_notification_config] if args.key?(:push_notification_config) end |