Class: Google::Apis::WorkspaceeventsV1::TaskStatus
- Inherits:
-
Object
- Object
- Google::Apis::WorkspaceeventsV1::TaskStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb
Overview
A container for the status of a task
Instance Attribute Summary collapse
-
#message ⇒ Google::Apis::WorkspaceeventsV1::Message
Message is one unit of communication between client and server.
-
#state ⇒ String
The current state of this task Corresponds to the JSON property
state. -
#timestamp ⇒ String
Timestamp when the status was recorded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TaskStatus
constructor
A new instance of TaskStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TaskStatus
Returns a new instance of TaskStatus.
1023 1024 1025 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1023 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ Google::Apis::WorkspaceeventsV1::Message
Message is one unit of communication between client and server. It is
associated with a context and optionally a task. Since the server is
responsible for the context definition, it must always provide a context_id in
its messages. The client can optionally provide the context_id if it knows the
context to associate the message to. Similarly for task_id, except the server
decides if a task is created and whether to include the task_id.
Corresponds to the JSON property message
1011 1012 1013 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1011 def @message end |
#state ⇒ String
The current state of this task
Corresponds to the JSON property state
1016 1017 1018 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1016 def state @state end |
#timestamp ⇒ String
Timestamp when the status was recorded. Example: "2023-10-27T10:00:00Z"
Corresponds to the JSON property timestamp
1021 1022 1023 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1021 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1028 1029 1030 1031 1032 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1028 def update!(**args) @message = args[:message] if args.key?(:message) @state = args[:state] if args.key?(:state) @timestamp = args[:timestamp] if args.key?(:timestamp) end |