Class: Google::Apis::WorkspaceeventsV1::TaskStatusUpdateEvent
- Inherits:
-
Object
- Object
- Google::Apis::WorkspaceeventsV1::TaskStatusUpdateEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb
Overview
TaskStatusUpdateEvent is a delta even on a task indicating that a task has changed.
Instance Attribute Summary collapse
-
#context_id ⇒ String
The id of the context that the task belongs to Corresponds to the JSON property
contextId. -
#final ⇒ Boolean
(also: #final?)
Whether this is the last status update expected for this task.
-
#metadata ⇒ Hash<String,Object>
Optional metadata to associate with the task update.
-
#status ⇒ Google::Apis::WorkspaceeventsV1::TaskStatus
A container for the status of a task Corresponds to the JSON property
status. -
#task_id ⇒ String
The id of the task that is changed Corresponds to the JSON property
taskId.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TaskStatusUpdateEvent
constructor
A new instance of TaskStatusUpdateEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TaskStatusUpdateEvent
Returns a new instance of TaskStatusUpdateEvent.
1099 1100 1101 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_id ⇒ String
The id of the context that the task belongs to
Corresponds to the JSON property contextId
1076 1077 1078 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1076 def context_id @context_id end |
#final ⇒ Boolean Also known as: final?
Whether this is the last status update expected for this task.
Corresponds to the JSON property final
1081 1082 1083 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1081 def final @final end |
#metadata ⇒ Hash<String,Object>
Optional metadata to associate with the task update.
Corresponds to the JSON property metadata
1087 1088 1089 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1087 def @metadata end |
#status ⇒ Google::Apis::WorkspaceeventsV1::TaskStatus
A container for the status of a task
Corresponds to the JSON property status
1092 1093 1094 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1092 def status @status end |
#task_id ⇒ String
The id of the task that is changed
Corresponds to the JSON property taskId
1097 1098 1099 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1097 def task_id @task_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1104 def update!(**args) @context_id = args[:context_id] if args.key?(:context_id) @final = args[:final] if args.key?(:final) @metadata = args[:metadata] if args.key?(:metadata) @status = args[:status] if args.key?(:status) @task_id = args[:task_id] if args.key?(:task_id) end |