Class: Google::Apis::WorkspaceeventsV1::TaskStatusUpdateEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workspaceevents_v1/classes.rb,
lib/google/apis/workspaceevents_v1/representations.rb,
lib/google/apis/workspaceevents_v1/representations.rb

Overview

TaskStatusUpdateEvent is a delta even on a task indicating that a task has changed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TaskStatusUpdateEvent

Returns a new instance of TaskStatusUpdateEvent.



1066
1067
1068
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1066

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_idString

The id of the context that the task belongs to Corresponds to the JSON property contextId

Returns:

  • (String)


1043
1044
1045
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1043

def context_id
  @context_id
end

#finalBoolean Also known as: final?

Whether this is the last status update expected for this task. Corresponds to the JSON property final

Returns:

  • (Boolean)


1048
1049
1050
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1048

def final
  @final
end

#metadataHash<String,Object>

Optional metadata to associate with the task update. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


1054
1055
1056
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1054

def 
  @metadata
end

#statusGoogle::Apis::WorkspaceeventsV1::TaskStatus

A container for the status of a task Corresponds to the JSON property status



1059
1060
1061
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1059

def status
  @status
end

#task_idString

The id of the task that is changed Corresponds to the JSON property taskId

Returns:

  • (String)


1064
1065
1066
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1064

def task_id
  @task_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1071
1072
1073
1074
1075
1076
1077
# File 'lib/google/apis/workspaceevents_v1/classes.rb', line 1071

def update!(**args)
  @context_id = args[:context_id] if args.key?(:context_id)
  @final = args[:final] if args.key?(:final)
  @metadata = args[:metadata] if args.key?(:metadata)
  @status = args[:status] if args.key?(:status)
  @task_id = args[:task_id] if args.key?(:task_id)
end